==> index_now-1.0.3.tar.gz: index_now/src/Form/ModuleSettingsForm.php <==
<?php

namespace Drupal\index_now\Form;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Module settings form.
 */
class ModuleSettingsForm extends ConfigFormBase {

  /**
   * The commerce product types list.
   *
   * @var array
   */
  protected $productsTypes;

  /**
   * The node types list.
   *
   * @var array
   */
  protected $nodeTypes;

  /**
   * The vocabularies list.
   *
   * @var array
   */
  protected $vocabularies;

  /**
   * The Uuid service.
   *
   * @var \Drupal\Component\Uuid\UuidInterface
   */
  protected $uuid;

  /**
   * Tells if the node module is installed.
   *
   * @var bool
   */
  protected $isNodeEnabled;

  /**
   * Tells if the taxonomy module is installed.
   *
   * @var bool
   */
  protected $isTaxonomyEnabled;

  /**
   * Tells if the commerce product module is installed.
   *
   * @var bool
   */
  protected $isCommerceProductEnabled;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * The form construct.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   *   The uuid service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    ModuleHandlerInterface $module_handler,
    StateInterface $state,
    UuidInterface $uuid
  ) {
    parent::__construct($config_factory);
    $this->isTaxonomyEnabled = $module_handler->moduleExists('taxonomy');
    $this->isNodeEnabled = $module_handler->moduleExists('node');
    $this->isCommerceProductEnabled = $module_handler->moduleExists('commerce_product');
    $this->state = $state;
    $this->uuid = $uuid;
    $this->productsTypes = [];
    $this->vocabularies = [];
    $this->nodeTypes = [];

    if ($this->isCommerceProductEnabled) {
      $this->productsTypes = $entity_type_manager
        ->getStorage('commerce_product_type')
        ->loadMultiple();
    }

    if ($this->isTaxonomyEnabled) {
      $this->vocabularies = $entity_type_manager
        ->getStorage('taxonomy_vocabulary')
        ->loadMultiple();
    }
    if ($this->isNodeEnabled) {
      $this->nodeTypes = $entity_type_manager
        ->getStorage('node_type')
        ->loadMultiple();
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('module_handler'),
      $container->get('state'),
      $container->get('uuid')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'index_now_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'index_now.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    // Check if there's an API key.
    $api_key = $this->state->get('index_now_api_key');

    if (empty($api_key)) {
      // We don't use service messenger because the warning remains
      // after the key has been generated until we reload the page.
      $form['no_keyfile'] = [
        '#markup' => "<p>⚠️ " . $this->t("Index now API key has not been generated yet. You must generate it if you want to use Index Now on this environment.") . "</p>",
      ];

      $form['generate_keyfile'] = [
        '#type' => 'button',
        '#value' => $this->t("Generate the API key"),
        '#name' => 'generate_apikey',
        '#attributes' => [
          'class' => [
            'button',
            'button-primary',
          ],
        ],
      ];
    }

    if ($this->isNodeEnabled || $this->isTaxonomyEnabled || $this->isCommerceProductEnabled) {
      $form['tabs'] = [
        '#type' => 'vertical_tabs',
        '#title' => $this->t("Restrict use"),
      ];
    }

    if ($this->isNodeEnabled) {
      $form['node'] = [
        '#type' => 'details',
        '#title' => $this->t("Content types"),
        '#group' => 'tabs',
      ];

      $node_types = [];
      /** @var \Drupal\node\Entity\NodeType $node_type */
      foreach ($this->nodeTypes as $machine_name => $node_type) {
        $node_types[$machine_name] = $node_type->get('name');
      }

      $form['node']['exclude_node_types'] = [
        '#type' => 'checkboxes',
        '#options' => $node_types,
        '#title' => $this->t("Exclude node types"),
        '#description' => $this->t("Selected node types won't use Index now"),
        '#default_value' => $this->config('index_now.settings')
          ->get('exclude_node_types'),
      ];
    }

    if ($this->isTaxonomyEnabled) {
      $form['taxonomy'] = [
        '#type' => 'details',
        '#title' => $this->t("Taxonomies"),
        '#group' => 'tabs',
      ];

      $vocabularies = [];
      /** @var \Drupal\taxonomy\Entity\Vocabulary $vocabulary */
      foreach ($this->vocabularies as $machine_name => $vocabulary) {
        $vocabularies[$machine_name] = $vocabulary->get('name');
      }

      $form['taxonomy']['exclude_vocabularies'] = [
        '#type' => 'checkboxes',
        '#options' => $vocabularies,
        '#title' => $this->t("Exclude vocabularies"),
        '#description' => $this->t("Selected vocabularies won't use Index now"),
        '#default_value' => $this->config('index_now.settings')
          ->get('exclude_vocabularies'),
      ];
    }

    if ($this->isCommerceProductEnabled) {
      $form['commerce_product'] = [
        '#type' => 'details',
        '#title' => $this->t("Products types"),
        '#group' => 'tabs',
      ];

      $products_types = [];
      /** @var \Drupal\commerce_product\Entity\ProductType $product_type */
      foreach ($this->productsTypes as $machine_name => $product_type) {
        $products_types[$machine_name] = $product_type->label();
      }

      $form['commerce_product']['exclude_commerce_product_types'] = [
        '#type' => 'checkboxes',
        '#options' => $products_types,
        '#title' => $this->t("Exclude products types"),
        '#description' => $this->t("Selected products types won't use Index now"),
        '#default_value' => $this->config('index_now.settings')
          ->get('exclude_commerce_product_types'),
      ];
    }

    $form['default_engine'] = [
      '#type' => 'radios',
      '#options' => [
        'bing' => 'Microsoft Bing',
        'yandex' => 'Yandex',
      ],
      '#title' => $this->t("Default search engine to interact with"),
      '#description' => $this->t("Since november 2021, if you interact with one search engine, you interact with all."),
      '#default_value' => $this->config('index_now.settings')
        ->get('default_engine') ?? 'bing',
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if ($triggering_element['#name'] == 'generate_apikey') {
      // Generate a random API key.
      $api_key = $this->uuid->generate();

      // Store the API key.
      $this->state->set('index_now_api_key', $api_key);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('index_now.settings');
    $config->set('default_engine', $form_state->getValue('default_engine'));
    if ($this->isNodeEnabled) {
      $config->set('exclude_node_types', $form_state->getValue('exclude_node_types'));
    }
    if ($this->isTaxonomyEnabled) {
      $config->set('exclude_vocabularies', $form_state->getValue('exclude_vocabularies'));
    }
    if ($this->isCommerceProductEnabled) {
      $config->set('exclude_commerce_product_types', $form_state->getValue('exclude_commerce_product_types'));
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}

==> index_now-1.0.6.tar.gz: index_now/src/Form/ModuleSettingsForm.php <==
<?php

namespace Drupal\index_now\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\index_now\Service\IndexNowKeyManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Module settings form.
 */
class ModuleSettingsForm extends ConfigFormBase {

  /**
   * The Index Now key manager service.
   *
   * @var \Drupal\index_now\IndexNowKeyManagerInterface
   */
  protected $indexNowKeyManager;

  /**
   * Tells if the node module is installed.
   *
   * @var bool
   */
  protected $isNodeEnabled;

  /**
   * Tells if the taxonomy module is installed.
   *
   * @var bool
   */
  protected $isTaxonomyEnabled;

  /**
   * Tells if the commerce product module is installed.
   *
   * @var bool
   */
  protected $isCommerceProductEnabled;

  /**
   * The node types list.
   *
   * @var array
   */
  protected $nodeTypes;

  /**
   * The commerce product types list.
   *
   * @var array
   */
  protected $productsTypes;

  /**
   * The vocabularies list.
   *
   * @var array
   */
  protected $vocabularies;

  /**
   * The form construct.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\index_now\IndexNowKeyManagerInterface $index_now_key_manager
   *   The Index Now key manager.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    ModuleHandlerInterface $module_handler,
    IndexNowKeyManagerInterface $index_now_key_manager
  ) {
    parent::__construct($config_factory);
    $this->indexNowKeyManager = $index_now_key_manager;
    $this->isTaxonomyEnabled = $module_handler->moduleExists('taxonomy');
    $this->isNodeEnabled = $module_handler->moduleExists('node');
    $this->isCommerceProductEnabled = $module_handler->moduleExists('commerce_product');
    $this->productsTypes = [];
    $this->vocabularies = [];
    $this->nodeTypes = [];

    if ($this->isCommerceProductEnabled) {
      $this->productsTypes = $entity_type_manager
        ->getStorage('commerce_product_type')
        ->loadMultiple();
    }

    if ($this->isTaxonomyEnabled) {
      $this->vocabularies = $entity_type_manager
        ->getStorage('taxonomy_vocabulary')
        ->loadMultiple();
    }
    if ($this->isNodeEnabled) {
      $this->nodeTypes = $entity_type_manager
        ->getStorage('node_type')
        ->loadMultiple();
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('module_handler'),
      $container->get('index_now.apikey.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'index_now_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'index_now.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    // Check if there's an API key.
    $api_key = $this->indexNowKeyManager->getKey();

    if (empty($api_key)) {
      // We don't use service messenger because the warning remains
      // after the key has been generated until we reload the page.
      $form['no_keyfile'] = [
        '#markup' => "<p>⚠️ " . $this->t("Index now API key has not been generated yet. You must generate it if you want to use Index Now on this environment.") . "</p>",
      ];

      $form['generate_keyfile'] = [
        '#type' => 'button',
        '#value' => $this->t("Generate the API key"),
        '#name' => 'generate_apikey',
        '#attributes' => [
          'class' => [
            'button',
            'button-primary',
          ],
        ],
      ];
    }

    if ($this->isNodeEnabled || $this->isTaxonomyEnabled || $this->isCommerceProductEnabled) {
      $form['tabs'] = [
        '#type' => 'vertical_tabs',
        '#title' => $this->t("Restrict use"),
      ];
    }

    if ($this->isNodeEnabled) {
      $form['node'] = [
        '#type' => 'details',
        '#title' => $this->t("Content types"),
        '#group' => 'tabs',
      ];

      $node_types = [];
      /** @var \Drupal\node\Entity\NodeType $node_type */
      foreach ($this->nodeTypes as $machine_name => $node_type) {
        $node_types[$machine_name] = $node_type->get('name');
      }

      $form['node']['exclude_node_types'] = [
        '#type' => 'checkboxes',
        '#options' => $node_types,
        '#title' => $this->t("Exclude node types"),
        '#description' => $this->t("Selected node types won't use Index now"),
        '#default_value' => $this->config('index_now.settings')
          ->get('exclude_node_types') ?? [],
      ];
    }

    if ($this->isTaxonomyEnabled) {
      $form['taxonomy'] = [
        '#type' => 'details',
        '#title' => $this->t("Taxonomies"),
        '#group' => 'tabs',
      ];

      $vocabularies = [];
      /** @var \Drupal\taxonomy\Entity\Vocabulary $vocabulary */
      foreach ($this->vocabularies as $machine_name => $vocabulary) {
        $vocabularies[$machine_name] = $vocabulary->get('name');
      }

      $form['taxonomy']['exclude_vocabularies'] = [
        '#type' => 'checkboxes',
        '#options' => $vocabularies,
        '#title' => $this->t("Exclude vocabularies"),
        '#description' => $this->t("Selected vocabularies won't use Index now"),
        '#default_value' => $this->config('index_now.settings')
          ->get('exclude_vocabularies') ?? [],
      ];
    }

    if ($this->isCommerceProductEnabled) {
      $form['commerce_product'] = [
        '#type' => 'details',
        '#title' => $this->t("Products types"),
        '#group' => 'tabs',
      ];

      $products_types = [];
      /** @var \Drupal\commerce_product\Entity\ProductType $product_type */
      foreach ($this->productsTypes as $machine_name => $product_type) {
        $products_types[$machine_name] = $product_type->label();
      }

      $form['commerce_product']['exclude_commerce_product_types'] = [
        '#type' => 'checkboxes',
        '#options' => $products_types,
        '#title' => $this->t("Exclude products types"),
        '#description' => $this->t("Selected products types won't use Index now"),
        '#default_value' => $this->config('index_now.settings')
          ->get('exclude_commerce_product_types') ?? [],
      ];
    }

    $form['default_engine'] = [
      '#type' => 'radios',
      '#options' => [
        'bing' => 'Microsoft Bing',
        'indexnow' => 'IndexNow',
        'seznam' => 'Seznam.cz',
        'yandex' => 'Yandex',
      ],
      '#title' => $this->t("Default search engine to interact with"),
      '#description' => $this->t("Since november 2021, if you interact with one search engine, you interact with all."),
      '#default_value' => $this->config('index_now.settings')
        ->get('default_engine') ?? 'bing',
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if ($triggering_element['#name'] == 'generate_apikey') {
      $this->indexNowKeyManager->generateKey();
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('index_now.settings');
    $config->set('default_engine', $form_state->getValue('default_engine'));
    if ($this->isNodeEnabled) {
      $config->set('exclude_node_types', $form_state->getValue('exclude_node_types'));
    }
    if ($this->isTaxonomyEnabled) {
      $config->set('exclude_vocabularies', $form_state->getValue('exclude_vocabularies'));
    }
    if ($this->isCommerceProductEnabled) {
      $config->set('exclude_commerce_product_types', $form_state->getValue('exclude_commerce_product_types'));
    }
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
